.. _usecase_enterprise:

=========================
Jupyter in the Enterprise
=========================

.. contents:: Contents
   :local:

Description
-----------

Businesses, especially those that started their ‘digital transformation’ journey, are producing
ever-increasing volumes of data. Enterprise data science aims to unearth the hidden value of
those digital assets, which are typically siloed, uncategorized, and inaccessible to humans.

Jupyter and JupyterHub can play a major role in related initiatives, especially in companies
with an established open-source culture. The intent of this page is to provide you with
ideas how Jupyter technology can fit into *your* organization's processes and system
landscapes, by providing real-world examples and showcases.


Example Use-Cases
-----------------

- `Beyond Interactive: Notebook Innovation at Netflix <https://medium.com/netflix-techblog/notebook-innovation-591ee3221233>`_

  - `Part 2: Scheduling Notebooks at Netflix <https://medium.com/netflix-techblog/scheduling-notebooks-348e6c14cfd6>`_

- `PayPal Notebooks: Data science and machine learning at scale, powered by Jupyter <https://conferences.oreilly.com/jupyter/jup-ny/public/schedule/detail/68405>`_ (JupyterCon 2018 · `video <https://youtu.be/KVGrACWVUgE>`_)

- `Bloomberg BQuant platform <https://mingze-gao.com/posts/bloomberg-bquant/>`_

- `Jupyter & Python in the corporate LAN <https://medium.com/@olivier.borderies/jupyter-python-in-the-corporate-lan-109e2ffde897>`_

- `DevOps Intelligence with JupyterHub <https://nbviewer.jupyter.org/github/jhermann/jupyter-by-example/blob/master/complete-scenarios/devops-intelligence.ipynb>`_


.. note::
    We're actively working on this section of the documentation to improve
    it for you. If you've got a suggestion for a resource that would be helpful, please
    create an issue or a pull request!
